@@ -1,7 +1,7 @@
 
 /*
 	VoIPong Voice Over IP Sniffer
-	Copyright (C) 2004 Murat Balaban <murat || enderunix.org>
+	Copyright (C) 2005 Murat Balaban <murat || enderunix.org>
 	All rights reserved.
 
 	This program is free software; you can redistribute it and/or
@@ -23,13 +23,19 @@
 #define VOIPONG_H
 
 #define PROGRAM	"EnderUNIX VOIPONG Voice Over IP Sniffer"
-#define VERSION "Release 1.1"
+#define VERSION "Release 2.0"
 #define COPYRIGHT "(c) Murat Balaban http://www.enderunix.org/"
 
-#include <voipongrtp.h>
+#include <voipongvoip.h>
 
 enum {
-	ERRBUFSIZ = 1024
+	ERRBUFSIZ = 1024,
+	MAXSBUFSIZ = 128,
+	MAXMBUFSIZ = 512,
+	MAXBUFSIZ = 1024,
+	MAXLBUFSIZ = 2048,
+	MAXXBUFSIZ = 4096,
+	MAXXXBUFSIZ = 8192
 };
 
 void graceful_shutdown();
@@ -37,11 +43,8 @@ void reload();
 void usage();
 void wexit(int);
 void waitforevents(void);
-void worker_create(rtp_session **);
-int worker_isexist(int ip1,  int ip2, int port1, int port2);
+void process_deadchild(void);
 	  
-void childmain(rtp_session *);
-
 void init_config();
 void get_initcfgvals();
 
