@@ -23,7 +23,11 @@
 #ifndef VOIPONGPCAP_H
 #define VOIPONGPCAP_H	1
 
-#define	ODD(x) ((x) % 2)
+#define isodd(x)  (x & 1)
+#define iseven(x)  !(x & 1)
+
+#include <pcap.h>
+#include <voipongnet.h>
 
 typedef struct voipstat voipstat;
 
@@ -37,9 +41,17 @@ struct voipstat {
 voipstat * getstats();
 void setstats(voipstat *s);
 
-int initpcap(char *errbuf);
+int initpcap(int, char *, char *errbuf);
 int getdllen();
+void peekpcap(int, pcap_handler);
+pcap_t *getpcapt();
 
 
 
+void packet_handler(u_char *udata, const struct pcap_pkthdr *pkthdr, const u_char *packet);
+void packet_handler_lfp(vnet *, u_char *udata, const struct pcap_pkthdr *pkthdr, const u_char *packet);
+void packet_handler_lra(vnet *, u_char *udata, const struct pcap_pkthdr *pkthdr, const u_char *packet);
+void packet_handler_fixed(vnet *, u_char *udata, const struct pcap_pkthdr *pkthdr, const u_char *packet);
+
+
 #endif
