@@ -4,7 +4,7 @@
 
 /*
 	VoIPong Voice Over IP Sniffer
-	Copyright (C) 2004 Murat Balaban <murat || enderunix.org>
+	Copyright (C) 2005 Murat Balaban <murat || enderunix.org>
 	All rights reserved.
 
 	This program is free software; you can redistribute it and/or
@@ -27,15 +27,16 @@
 
 #define AUTHCLIRBUFSIZ	8192
 
-int open_server_sockets();
-void init_socket();
-void close_all_connections();
+int open_server_socket();
 void add_to_select_set(int);
 void remove_from_select_set(int);
+void sockets_run(void);
+/*
+void init_socket();
+void close_all_connections();
 void setselecttimeout(int val);
 int getselecttimeout(void);
-void sockets_run(void);
 int open_server_socket(int, int *);
-void peekpcap(void);
+*/
 
 #endif
